@@ -9,13 +9,13 @@
 ##' Nonmem (e.g. observations or subjects that are not part of the analysis)}
 ##' }
 ##' 
-##' @param file A Nonmem control stream or output file from Nonmem
-##'     (.mod or .lst)
-##' @param file.mod The input control stream. Default is to look for
-##'     \"file\" with extension changed to .mod (PSN style). You can
-##'     also supply the path to the file, or you can provide a
-##'     function that translates the output file path to the input
-##'     file path. The default behavior can be configured using
+##' @param file Path to a Nonmem control stream or output file from
+##'     Nonmem (.mod or .lst)
+##' @param file.mod The input control stream file path. Default is to
+##'     look for \"file\" with extension changed to .mod (PSN
+##'     style). You can also supply the path to the file, or you can
+##'     provide a function that translates the output file path to the
+##'     input file path. The default behavior can be configured using
 ##'     NMdataConf. See dir.data too.
 ##' @param col.id The name of the subject ID variable, default is
 ##'     "ID".
@@ -59,11 +59,6 @@
 ##'     function must take one character argument and return another
 ##'     character string. As example, see NMdataConf()$modelname. The
 ##'     default can be configured using NMdataConf.
-##' @param use.rds If an rds file is found with the exact same name
-##'     (except for .rds instead of say .csv) as the input data file
-##'     mentioned in the Nonmem control stream, should this be used
-##'     instead? The default is yes, and NMwriteData will create this
-##'     by default too. Default can be configured using NMdataConf.
 ##' @param dir.data The data directory can only be read from the
 ##'     control stream (.mod) and not from the output file (.lst). So
 ##'     if you only have the output control stream, use dir.data to
@@ -74,6 +69,11 @@
 ##' @param translate.input Default is TRUE, meaning that input data
 ##'     column names are translated according to $INPUT section in
 ##'     Nonmem listing file.
+##' @param formats.read Prioritized input data file formats to look
+##'     for and use if found. Default is c("rds","csv") which means
+##'     \code{rds} will be used if found, and \code{csv} if
+##'     not. \code{fst} is possible too. Default can be modified using
+##'     \code{NMdataConf()}. 
 ##' @param quiet The default is to give some information along the way
 ##'     on what data is found. But consider setting this to TRUE for
 ##'     non-interactive use. Default can be configured using
@@ -88,12 +88,14 @@
 ##'     as.fun="data.table". The default can be configured using
 ##'     NMdataConf.
 ##' @param rep.count Nonmem includes a counter of tables in the
-##'     written data files. These are often not useful. Especially for
-##'     NMscanData output it can be meaningless because multiple
-##'     tables can be combined so this information is not unique
-##'     across those source tables. However, if rep.count is TRUE (not
-##'     default), this will be carried forward and added as a column
-##'     called NMREP. The argument is passed to NMscanTables.
+##'     written data files. This does not relate to the order of the
+##'     $TABLE statements but to cases where a $TABLE statement is run
+##'     repeatedly. E.g., in combination with the SUBPROBLEMS feature
+##'     in Nonmem, it is useful to keep track of the table
+##'     (repetition) number. If rep.count is TRUE, this will be
+##'     carried forward and added as a column called NMREP. This is
+##'     default behavior when more than one $TABLE repetition is found
+##'     in data. The argument is passed to NMscanTables.
 ##' @param order.columns If TRUE (default), NMorderColumns is used to
 ##'     reorder the columns before returning the data. NMorderColumns
 ##'     will be called with alpha=FALSE, so columns are not sorted
@@ -118,7 +120,11 @@
 ##'     NMdataConf() too.
 ##' @param skip.absent Skip missing output table files with a warning?
 ##'     Default is FALSE in which case an error is thrown.
-##' @param tab.count Deprecated. Use rep.count.
+##' @param tab.count Deprecated. Use \code{rep.count}.
+##' @param use.rds Deprecated - use \code{formats.read} instead. If
+##'     provided (though not recommended), this will overwrite
+##'     \code{formats.read}, and only formats \code{rds} and
+##'     \code{csv} can be used. 
 ##'
 ##' @details This function makes it very easy to collect the data from
 ##'     a Nonmem run.
@@ -145,7 +151,9 @@
 ##'  \item{NULL}{The NULL argument to specify missing value string in input data is not respected. If delimited input data is read (as opposed to rds files), missing values are assumed to be represented by dots (.).}
 ##' }
 ##' @examples
+##' \dontrun{
 ##' res1 <- NMscanData(system.file("examples/nonmem/xgxr001.lst", package="NMdata"))
+##' }
 ##' @return A data set of class 'NMdata'.
 ##' @family DataRead
 ##' @import data.table
@@ -154,11 +162,15 @@
 
 NMscanData <- function(file, col.row, use.input, merge.by.row,
                        recover.rows,file.mod,dir.data,file.data,
-                       translate.input=TRUE, quiet, use.rds,
+                       translate.input=TRUE, quiet, formats.read,
                        args.fread, as.fun, col.id="ID", modelname,
                        col.model, col.nmout,rep.count,
                        order.columns=TRUE, check.time, tz.lst,
-                       skip.absent=FALSE,tab.count) {
+                       skip.absent=FALSE,
+                       ## Deprecated
+                       tab.count,
+                       use.rds
+                       ) {
 
 #### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
     
@@ -194,6 +206,7 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
 #### Section start: Process arguments  ####
 
     file <- filePathSimple(file)
+    if(length(file)>1) stop("Argument `file` is of length > 1. NMscanData() does not support reading multiple models. To do that, please use NMscanMultiple().")
     if(!file.exists(file)) messageWrap(paste0("Model file ",file," does not exist."),fun.msg=stop)
     dir <- dirname(file)
 
@@ -206,7 +219,7 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
     if(missing(tz.lst)) tz.lst <- NULL
     if(missing(as.fun)) as.fun <- NULL
     if(missing(quiet)) quiet <- NULL
-    if(missing(use.rds)) use.rds <- NULL
+    if(missing(formats.read)) formats.read <- NULL
     if(missing(args.fread)) args.fread <- NULL
 
     check.time <- NMdataDecideOption("check.time",check.time)
@@ -216,13 +229,35 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
     if(missing(recover.rows)) recover.rows <- NULL
     recover.rows <- NMdataDecideOption("recover.rows",recover.rows)
     quiet <- NMdataDecideOption("quiet",quiet)
-    use.rds <- NMdataDecideOption("use.rds",use.rds)
+    formats.read <- NMdataDecideOption("formats.read",formats.read)
     args.fread <- NMdataDecideOption("args.fread",args.fread)
     ## if null, rep.count will later be set to TRUE if NMREP varies
+
+    ## deprecated 2023-06-20
+    use.rds <- deprecatedArg(oldarg="use.rds",msg="Use `formats` instead. Overwriting `formats.read`.")
+    if(!is.null(use.rds)&&use.rds){
+        formats.read <- c("rds","csv")
+    }
+    if(!is.null(use.rds)&&!use.rds){
+        formats.read <- setdiff(formats.read,c("rds"))
+    }
+    
+    
+### deprecated before 2023-06-12
+    ## if(!missing(tab.count)) .Deprecated("rep.count",old="tab.count")
+
+    if(!missing(tab.count)||!missing(rep.count)){
+        args <- getArgs()
+        rep.count <- deprecatedArg(oldarg="tab.count",newarg="rep.count",args=args)
+    }
     if(missing(rep.count)) rep.count <- NULL
-    if(!missing(tab.count)) .Deprecated("rep.count",old="tab.count")
-    if(!is.null(rep.count)&&!missing(tab.count)) stop("Use rep.count, not tab.count.")
-    if(!missing(tab.count)) rep.count <- tab.count
+    
+    ## if(!missing(tab.count)){
+    ##     if(!missing(rep.count)) stop("keepNames is deprecated. Use only keep.names.")
+    ##     message("keepNames is deprecated. Please use keep.names.")
+    ##     rep.count <- tab.count
+    ## }
+
     
     runname <- modelname(file)
     ## file.mod is treated later if we need the input control stream
@@ -310,7 +345,7 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
                                       ,file.data=file.data
                                       ,quiet=TRUE
                                       ,translate=translate.input
-                                      ,use.rds=use.rds
+                                      ,formats.read=formats.read
                                       ,applyFilters=FALSE
                                       ,args.fread=args.fread
                                       ,as.fun="data.table"
@@ -416,12 +451,14 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
             mtime.mod <- file.info.mod$mtime
             
             if(mtime.mod>testtime.lst){
-                messageWrap(paste0("input control stream (",file.mod,") is newer than output control stream (",file,"). Seems like model has been edited since last run. If data sections have been edited, this can corrupt results."),
+                ## messageWrap(paste0("input control stream (",file.mod,") is newer than output control stream (",file,"). Seems like model has been edited since last run. If data sections have been edited, this can corrupt results."),
+                messageWrap("Input control stream is newer than output control stream.",
                             fun.msg=warning)
                 time.ok <- c(time.ok,"mod > lst")
             }
             if(mtime.mod>min(meta.output[,file.mtime])){
-                messageWrap(paste0("input control stream (",file.mod,") is newer than output tables. Seems like model has been edited since last run. If data sections have been edited, this can corrupt results."),
+                ## messageWrap(paste0("input control stream (",file.mod,") is newer than output tables. Seems like model has been edited since last run. If data sections have been edited, this can corrupt results."),
+                messageWrap("Input control stream is newer than output tables.",
                             fun.msg=warning)
                 time.ok <- c(time.ok,"mod > output")
             }
@@ -549,7 +586,7 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
 
             ## if no method is specified, search for possible col.row to help the user
             if(search.col.row){
-                msg0 <- searchColRow(file,file.mod=file.mod,dir.data,file.data,translate.input,use.rds,args.fread,col.id,tab.row)
+                msg0 <- searchColRow(file,file.mod=file.mod,dir.data,file.data,translate.input,formats.read,args.fread,col.id,tab.row)
                 msg <- paste0(msg0,"\n",
                               "To skip this check, please use merge.by.row=TRUE or merge.by.row=FALSE.")
                 messageWrap(msg,fun.msg=message)
