@@ -25,6 +25,11 @@
 ##'     only used to check whether the row counter is in the data.
 ##' @param skip.absent Skip missing output table files with a warning?
 ##'     Default is FALSE in which case an error is thrown.
+##' @param meta.only If TRUE, tables are not read, only a table is
+##'     returned showing what tables were found and some available
+##'     meta information. Notice, not all meta information (e.g.,
+##'     dimensions) are available because the tables need to be read
+##'     to derive that.
 ##' @return A list of all the tables as data.frames. If details=TRUE,
 ##'     this is in one element, called data, and meta is another
 ##'     element. If not, only the data is returned.
@@ -34,7 +39,7 @@
 ##' @import data.table
 ##' @export
 
-NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,details,skip.absent=FALSE){
+NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,details,skip.absent=FALSE,meta.only=FALSE){
     
 #### Section start: Dummy variables, only not to get NOTE's in package checks ####
 
@@ -69,7 +74,9 @@ NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,d
     }    
     col.row <- NMdataDecideOption("col.row",col.row)
 
-    if(!missing(details)) message("NMscanTables: argument details is deprecated.")
+    ## if(!missing(details)) message("NMscanTables: argument details is deprecated.")
+    args <- getArgs()
+    deprecatedArg(oldarg="details",args=args)
     
     dir <- dirname(file)
     extract.info <- function(x,NAME,default){
@@ -82,9 +89,9 @@ NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,d
         info
     }
     
-    lines.table <- NMreadSection(file,section="TABLE",keepName=FALSE,
-                                 keepComments=FALSE,keepEmpty=FALSE,
-                                 asOne=FALSE, simplify=FALSE)
+    lines.table <- NMreadSection(file,section="TABLE",keep.name=FALSE,
+                                 keep.comments=FALSE,keep.empty=FALSE,
+                                 as.one=FALSE, simplify=FALSE)
     if(length(lines.table)==0) {
         messageWrap("No TABLE sections found in control stream. Please inspect the control stream.",
                     fun.msg=stop)
@@ -114,19 +121,26 @@ NMscanTables <- function(file,as.fun,quiet,rep.count=FALSE,col.id="ID",col.row,d
     }
     tables <- list()
 
-    meta[,exists:=TRUE]
+    meta[,exists:=file.exists(file)]
+    meta[,filetype:="output"]    
+    meta[,file.mtime:=file.mtime(file)]
+
+    if(meta.only){
+        setcolorder(meta,intersect(c("source","name","nrow","ncol","nid","level","scope","has.col.row","has.col.id","full.length","filetype","format",
+                                     "file.mtime","file"),colnames(meta)))
+        return(as.fun(meta))
+    }
+
+######## read data
     for(I in 1:nrow(meta)){
-        if(!file.exists(meta[I,file])) {
-            meta[I,exists:=FALSE]
+        if(meta[I,!exists]) {
             if(skip.absent) {
                 messageWrap(paste0("NMscanTables: File not found: ",meta[I,file],". Skipping."),fun.msg=message)
-                ## meta <- meta[-I]
                 next
             }
-            stop(paste0("NMscanTables: File not found: ",meta[I,file],". Did you copy the lst file but forgot table
-file?"))
+            stop(paste0("NMscanTables: File not found: ",meta[I,file],". Did you copy the lst file but forgot table file?"))
         }
-            
+        
         tables[[I]] <- NMreadTab(meta[I,file],quiet=TRUE,rep.count=rep.count,showProgress=FALSE,as.fun=identity,header=meta[I,!noheader])
 ### to not include NMREP when counting columns
         ## dim.tmp <- dim(tables[[I]][,!colnames(tables[[I]])=="NMREP",with=FALSE])
@@ -197,12 +211,6 @@ file?"))
                )]
 
 
-    meta[,filetype:="output"]
-    ##
-    ##    meta[,full.length:=nrow==max(nrow)]
-    ## test if all  have same length within level. 
-    
-    meta[,file.mtime:=file.mtime(file)]
     ## sep not used so omitted 
     setcolorder(meta,intersect(c("source","name","nrow","ncol","nid","level","scope","has.col.row","has.col.id","full.length","filetype","format",
                                  "file.mtime","file"),colnames(meta)))
@@ -228,7 +236,7 @@ file?"))
     
     names(tables) <- meta[,name]
 
-    as.fun <- NMdataDecideOption("as.fun",as.fun)
+
     tables <- lapply(tables,as.fun)
     
     writeNMinfo(tables,list(tables=meta),byRef=TRUE)
