@@ -1,7 +1,7 @@
 ## library(devtools)
 ## setwd("tests/testthat")
 ## load_all()
-
+library(data.table)
 context("compareCols")
 
 test_that("basic",{
@@ -9,11 +9,13 @@ test_that("basic",{
     fileRef <- "testReference/compareCols_1.rds"
 
     pk <- readRDS(file=system.file("examples/data/xgxr2.rds",package="NMdata"))
-    pk.reduced <- copy(pk)
-    pk.reduced <- pk.reduced[1:(.N%/%2)]
+    ## pk.reduced <- copy(pk)
+    ## pk.reduced <- pk.reduced[1:(.N%/%2)]
+    pk.reduced <- pk[1:(.N%/%2)]
     pk.reduced[,CYCLE:=NULL]
     pk.reduced[,AMT:=as.character(AMT)]
 
+
     res1 <- compareCols(pk,pk.reduced)
 
     expect_equal_to_reference(res1,fileRef)
@@ -51,7 +53,7 @@ test_that("diff.only=FALSE, keepNames = F",{
 
     expect_equal_to_reference(res1,fileRef)
 
-    res2 <- compareCols(pk,pk.reduced,diff.only=FALSE,keepNames = F)
+    res2 <- compareCols(pk,pk.reduced,diff.only=FALSE,keep.names = F)
     expect_equal(res1,res2)
 })
 
